%global longver %%(echo %{version} | sed 's/\\(....\\)\\(..\\)\\(..\\)/\\1-\\2-\\3/g')

Summary:        C++ fast alternative to backtracking RE engines
Name:           re2
Version:        20220601
Release:        6%{?dist}
License:        BSD
URL:            https://github.com/google/re2/
Source0:        https://github.com/google/re2/archive/%{longver}.tar.gz

BuildRequires: cmake gcc-c++

%description
RE2 is a C++ library providing a fast, safe, thread-friendly alternative to
backtracking regular expression engines like those used in PCRE, Perl, and
Python.
Backtracking engines are typically full of features and convenient syntactic
sugar but can be forced into taking exponential amounts of time on even small
inputs.
In contrast, RE2 uses automata theory to guarantee that regular expression
searches run in time linear in the size of the input, at the expense of some
missing features (e.g back references and generalized assertions).

%package        devel
Summary:        C++ header files and library symbolic links for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
This package contains the C++ header files and symbolic links to the shared
libraries for %{name}. If you would like to develop programs using %{name},
you will need to install %{name}-devel.

%prep
%autosetup -n %{name}-%{longver}

%build
%cmake . \
    -DOVERRIDE_INSTALL_PREFIX=/usr \
    -DCMAKE_COLOR_MAKEFILE:BOOL=OFF \
    -DINSTALL_LIBDIR:PATH=%{_libdir} \
    "-GUnix Makefiles"

%cmake_build

%install
%cmake_install
rm -fv %{buildroot}%{_libdir}/libre2.a
mkdir -p %{buildroot}%{_libdir}/pkgconfig/
sed -i -e 's,@includedir@,%{_includedir},g' re2.pc
sed -i -e 's,@libdir@,%{_libdir},g' re2.pc
install -m 0644 re2.pc %{buildroot}%{_libdir}/pkgconfig/


%check
%make_build shared-test


%files
%license LICENSE
%doc AUTHORS CONTRIBUTORS README
%{_libdir}/libre2.so.9*

%files devel
%{_includedir}/re2/
%{_libdir}/libre2.so
%{_libdir}/pkgconfig/re2.pc
%{_libdir}/cmake/re2/*.cmake

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 20220601-6
- Rebuilt for loongarch release

* Wed Aug 7 2024 Chunsheng Luo <luffyluo@tencent.com> - 20220601-5
- Modify the version acquisition method to adapt to automatic upgrade

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 20220601-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 20220601-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 20220601-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Dec 16 2022 Miaojun Dong <zoedong@tencent.com> - 20220601-1
- initial build
